@@ -3,7 +3,7 @@ vfplotloc <- function( vals, eye, patternMap, outerColor, innerColor = NULL, bs
                        txtcolor = NULL, xminmax = 29, yminmax = 29, outerSymbol = "circles",
                        innerSymbol = "circles", outerSize = 1, innerSize = 1,
                        outerInch = 0.2, innerInch = 0.1,
-                       lengthLines = 2.5, thicknessLines = 2,
+                       lengthLines = 0, thicknessLines = 0,
                        outerBorderColor = NULL, innerBorderColor = NULL,
                        outerBorderThickness = 2, innerBorderThickness = 2 ) {
 
